==> haskell-hslua-objectorientation-2.3.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-C7kbWt6dKVeKDFC8wCZMmk
key:                  hslua-objectorientation-2.3.0-C7kbWt6dKVeKDFC8wCZMmk
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  a0c69cc69e0f4d632b67e662d3c86d3a
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-C7kbWt6dKVeKDFC8wCZMmk
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    exceptions-0.10.4 hslua-core-2.3.1-9ZPYagrpDfs3AMUspgQsAp
    hslua-marshalling-2.3.1-9Rohik5d6KSKKwPccGjR92
    hslua-typing-0.1.1-5UuBb12XXo1SekYM0noxF mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-objectorientation-2.3.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-objectorientation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-objectorientation
version:              2.3.0
visibility:           public
id:                   hslua-objectorientation-2.3.0-BtVRFSELh916HNgMidkxDu
key:                  hslua-objectorientation-2.3.0-BtVRFSELh916HNgMidkxDu
license:              MIT
copyright:            © 2021-2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  451ef8f6f22ebd96edb8b05e9c196b9a
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-objectorientation-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.0-BtVRFSELh916HNgMidkxDu
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    exceptions-0.10.4 hslua-core-2.3.1-7tP5g9DQ4OeKdOyVI81TL5
    hslua-marshalling-2.3.1-JCueeqDsAl64rAvJDWOXcX
    hslua-typing-0.1.1-E78oz3WRBt26g1uab1iM6c mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
